@@ -1,6 +1,7 @@
-from vietocr.model.cnn import CNN
-from vietocr.model.transformer import LanguageTransformer
-from vietocr.model.seq2seqv2 import Seq2Seq
+from vietocr.model.backbone.cnn import CNN
+from vietocr.model.seqmodel.transformer import LanguageTransformer
+from vietocr.model.seqmodel.seq2seq import Seq2Seq
+from vietocr.model.seqmodel.convseq2seq import ConvSeq2Seq
 from torch import nn
 
 class VietOCR(nn.Module):
@@ -18,6 +19,8 @@ class VietOCR(nn.Module):
             self.transformer = LanguageTransformer(vocab_size, **transformer_args)
         elif seq_modeling == 'seq2seq':
             self.transformer = Seq2Seq(vocab_size, **transformer_args)
+        elif seq_modeling == 'convseq2seq':
+            self.transformer = ConvSeq2Seq(vocab_size, **transformer_args)
         else:
             raise('Not Support Seq Model')
 
@@ -35,6 +38,7 @@ class VietOCR(nn.Module):
             outputs = self.transformer(src, tgt_input, tgt_key_padding_mask=tgt_key_padding_mask)
         elif self.seq_modeling == 'seq2seq':
             outputs = self.transformer(src, tgt_input)
-        
+        elif self.seq_modeling == 'convseq2seq': 
+            outputs = self.transformer(src, tgt_input)
         return outputs
 
